#include <curses.h>
#include <time.h>
#include "ui.h"

static WINDOW *board, *info, *chat;

/* Initialize the UI routines. Must be done before everything */
void ui_init()
{
    int x_max, y_max;

    initscr();

    /* Get screen parameters and see if we can work with this. */
    getmaxyx(stdscr, y_max, x_max);
    if (y_max < 13 || x_max < 40) {
	endwin();
	puts("Cannot use screen, wrong size");
	exit(0);
    }
    clear();

    /* Setup our windows */
    board = newwin(8, 16, 0, 0);
    info = newwin(8, x_max - 17, 0, 17);
    chat = newwin(y_max - 11, x_max, 9, 0);

    if (!(board && info && chat)) {
	endwin();
	puts("Couldn't initialize windows");
	exit(0);
    }

    /* Set scrolling attributes */
    scrollok(chat, TRUE);
    idlok(chat, TRUE);
    scrollok(info, TRUE);
    idlok(info, TRUE);

    /* Partition the workspace */
    mvhline(8, 0, ACS_HLINE, x_max);
    mvhline(y_max - 2, 0, ACS_HLINE, x_max);
    mvvline(0, 16, ACS_VLINE, 8);
    mvaddch(8, 16, ACS_BTEE);

    ui_update(0);
}

/* Shutdown. Done before exiting the program */
void ui_shutdown()
{
    delwin(board);
    delwin(info);
    delwin(chat);
    endwin();
}

void ui_chatmsg(char *msg)
{
    waddstr(chat, msg);
    wrefresh(chat);
}

void ui_infomsg(char *msg)
{
    waddstr(info, msg);
    wrefresh(info);
}

/* WARNING: The string returned here is STATIC! strdup it if you need it
 * elsewhere! */
char *ui_getmsg(char *out)
{
    static char msg[128];

    waddstr(chat, out);
    wrefresh(info);
    wgetnstr(chat, msg, 120);

    return msg;
}

/* Update some of the attributes of the ui */
void ui_update(float secs)
{
    int x_max, y_max;
    char buf[256];

    getmaxyx(stdscr, y_max, x_max);
    sprintf(buf, "CPU-Time used: %f secs", secs);
    mvaddstr(y_max - 1, 0, buf);
    refresh();
}

